# quakerHeritage
Project to support the collation of PDF data on the Quaker Meeting House Heritage Project into a database

[![Python 3.10](https://img.shields.io/badge/python-3.10-blue.svg)](https://www.python.org/downloads/release/python-3100/)
![PyPI](https://img.shields.io/badge/PyPI-v0.0.3-blue)
![status](https://img.shields.io/badge/status-released-green)

## Dependencies

### Required Python Libaries
* bs4
* numpy
* pandas
* pdfplumber
* requests

### Disclaimer

This project has been specifically coded for the Quaker Meeting House Heritage Project, both in hard-coded variables, and hard-coded parameters for extracting text. It is a tool to suit a very specific use-case and may not work if used otherwise. The project further depends on the files required being listed online at the URLs provided. If Britain Yearly Meeting takes down the website and associated pdfs, back-ups are available on the Internet Archive's Wayback Machine. The code can also be adapted to work with locally downloaded pdfs. go to Appendix: Hosting Errors to note the required changes. 

## Installation

    pip install quakerheritage

## Contributing

Feedback is both welcome and encouraged. If you use the code, or just find issues while browsing, please report them by [clicking here.](github.com/aclayden/quakerHeritage/issues)

## Licence

Distributed under [AGPL version 3.0](https://www.gnu.org/licenses/agpl-3.0.en.html)

## Contact

For queries please reach out via GitHub by either raising an issue or contacting me directly. https://github.com/aclayden
